@@ -1,10 +1,12 @@
 from qottoauth.api.base import QottoAuthApi, QottoAuthApiError
-from qottoauth.api.graphene import QottoAuthGrapheneApi
+from qottoauth.api.gql import QottoAuthGqlApi
 from qottoauth.api.test import QottoAuthTestApi
+from qottoauth.api.cached import QottoAuthCachedApi
 
 __all__ = [
     'QottoAuthApi',
     'QottoAuthApiError',
     'QottoAuthTestApi',
-    'QottoAuthGrapheneApi',
+    'QottoAuthGqlApi',
+    'QottoAuthCachedApi',
 ]
